package basicTurtlePackage;


import java.awt.Color;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.Toolkit;
import java.io.BufferedInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.net.URL;
import java.util.ArrayList;

import javax.imageio.ImageIO;
import javax.swing.JFrame;

/**  
 * File:	World.java - a windowed representation of the 
 * 			world in which our turtles can live and exist.
 * 			  
 * Date:	January 25, 2010
 * @author  Aleksandar Stefanovski
 * @version 1.0 
 */ 
public class World extends JFrame {

	// Protected world (global) variables
	protected int width, height; 
	protected ArrayList<Turtle> turtles;


	/**  
	 * Method:	Constructor method.
	 * Purpose: Creates a new object (instance) of this class.  
	 * 
	 * @param	none	
	 * @return 	none 
	 */  
	public World(String worldName) {
		// set the title bar to the worldName specified when the
		// world is being created.
		super(worldName);

		// default width and height (which can be changed later on)
		this.width = 640;
		this.height = 400;
		this.setSize(width,height);

		// make sure that when the X box is pressed
		// the program will exit
		this.setDefaultCloseOperation(EXIT_ON_CLOSE); 

		this.setVisible(true);                // make it visible
		
		// create a list object to store the turtles
		// we use ArrayList because we do not know how many turtles
		// are going to be in the world.
		this.turtles = new ArrayList<Turtle>();
	} // end constructor
	
	/**  
	 * Method:	paint
	 * Purpose: Gives the ability to paint on the screen.  
	 * 
	 * @param	g (Graphics)	
	 * @return 	none 
	 */
    public void paint(Graphics g) {
    	// set the background color
        g.setColor(Color.white);
        g.fillRect(0, 0, getWidth(), getHeight());
  
        if( turtles != null ) {	
	        for(Turtle eachTurtle:turtles) {
	        	eachTurtle.paint(g);
	        }
         	
        } // end if
    } // end paint

	/**  
	 * Method:	add
	 * Purpose: Adds a new turtle to the world, and repaints the world.  
	 * 
	 * @param	newTurtle (Turtle)	
	 * @return 	none 
	 */
    public void add(Turtle newTurtle) {
    	turtles.add(newTurtle);
    	repaint();
    } // end add
 
} // end class